==> fle-cli-1.1.6.tgz: package/lib/run.js <==
const fs = require('fs');
const path = require('path');
const utils = require('./utils');

module.exports = function (args, opts) {
  const pkg = require(path.resolve('./package.json'));
  const type = (pkg['fle-settings'] && pkg['fle-settings'].type) || args[1];

  const cmds = {
    lib: {
      dev: [
        'node node_modules/rollup-watch-fix/index.js',
        'node_modules/.bin/rollup -c node_modules/fle-build-lib/build/rollup.demo.config.js -w'
      ].join(' && '),
      build: [
        'node_modules/.bin/rimraf lib public/dist',
        'node_modules/.bin/rollup -c node_modules/fle-build-lib/build/rollup.lib.config.js',
        'node_modules/.bin/rollup -c node_modules/fle-build-lib/build/rollup.demo.config.js'
      ].join(' && ')
    },
    react: {
      dev: 'node_modules/.bin/webpack-dev-server --inline --progress --config node_modules/fle-build-react/build/webpack.config.js',
      build: 'node_modules/.bin/webpack --progress --hide-modules --config node_modules/fle-build-react/build/webpack.config.js'
    },
    vue: {
      dev: 'node_modules/.bin/webpack-dev-server --inline --progress --config node_modules/fle-build-vue/build/webpack.config.js',
      build: 'node_modules/.bin/webpack --progress --hide-modules --config node_modules/fle-build-vue/build/webpack.config.js'
    },
    app: {
      dev: 'node_modules/.bin/webpack-dev-server --inline --progress --config node_modules/fle-build-app/build/webpack.config.js',
      build: 'node_modules/.bin/webpack --progress --hide-modules --config node_modules/fle-build-app/build/webpack.config.js'
    }
  };

  if (Object.keys(cmds).indexOf(type) === -1) {
    console.log('');
    console.log('Please specify the project type: ' + Object.keys(cmds).join(', '));
    console.log('');

    process.exit();
  }

  utils.exec(cmds[type][args[0]], {
    NODE_ENV: args[0] === 'dev' ? 'development' : 'production',
    FLE_VCONSOLE: opts.log
  });
}

==> fle-cli-2.1.6.tgz: package/lib/run.js <==
const fs = require('fs');
const path = require('path');
const utils = require('./utils');

module.exports = function (args, opts) {
  const fle = require(path.resolve('fle.json'));
  const type = fle.type || args[1];

  const cmds = {
    lib: {
      dev: [
        'node node_modules/rollup-watch-fix/index.js',
        'node_modules/.bin/rollup -c node_modules/fle-build-lib/build/rollup.demo.config.js -w'
      ].join(' && '),
      build: [
        'node_modules/.bin/rimraf lib public/dist',
        'node_modules/.bin/rollup -c node_modules/fle-build-lib/build/rollup.lib.config.js',
        'node_modules/.bin/rollup -c node_modules/fle-build-lib/build/rollup.demo.config.js'
      ].join(' && ')
    },
    react: {
      dev: 'node_modules/.bin/webpack-dev-server --inline --progress --config node_modules/fle-build-react/build/webpack.config.js',
      build: [
        'node_modules/.bin/rimraf dist',
        'node_modules/.bin/webpack --progress --hide-modules --config node_modules/fle-build-react/build/webpack.config.js'
      ].join(' && ')
    },
    vue: {
      dev: 'node_modules/.bin/webpack-dev-server --inline --progress --config node_modules/fle-build-vue/build/webpack.config.js',
      build: [
        'node_modules/.bin/rimraf dist',
        'node_modules/.bin/webpack --progress --hide-modules --config node_modules/fle-build-vue/build/webpack.config.js'
      ].join(' && ')
    },
    app: {
      dev: 'node_modules/.bin/webpack-dev-server --inline --progress --config node_modules/fle-build-app/build/webpack.config.js',
      build: [
        'node_modules/.bin/rimraf dist',
        'node_modules/.bin/webpack --progress --hide-modules --config node_modules/fle-build-app/build/webpack.config.js'
      ].join(' && ')
    }
  };

  if (Object.keys(cmds).indexOf(type) === -1) {
    console.log('');
    console.log('Please specify the project type: ' + Object.keys(cmds).join(', '));
    console.log('');

    process.exit();
  }

  utils.exec(cmds[type][args[0]], {
    NODE_ENV: args[0] === 'dev' ? 'development' : 'production',
    FLE_VCONSOLE: opts.log
  });
}
